@@ -356,6 +356,48 @@ class IWidget(IWidgetInterface, ABC):
         textpos.centery = self._y + (self._h / 2)
         surface.blit(text, textpos)
 
+    def render_left_text(self, surface, text, color, bg_color=None):
+        """ Render text in the left side of the widget.
+
+        Parameters
+        ----------
+        surface : pygame.Surface
+        text : str
+        color : Color
+        bg_color : Color
+            If you specify the background color, it can render the text a
+            bit faster because it won't use alpha for a clear background.
+        """
+        if text is None:
+            return
+
+        text = self._font.render(text, 1, color, bg_color)
+        textpos = text.get_rect()
+        textpos.leftx = self._x
+        textpos.centery = self._y + (self._h / 2)
+        surface.blit(text, textpos)
+
+    def render_right_text(self, surface, text, color, bg_color=None):
+        """ Render text in the right side of the widget.
+
+        Parameters
+        ----------
+        surface : pygame.Surface
+        text : str
+        color : Color
+        bg_color : Color
+            If you specify the background color, it can render the text a
+            bit faster because it won't use alpha for a clear background.
+        """
+        if text is None:
+            return
+
+        text = self._font.render(text, 1, color, bg_color)
+        textpos = text.get_rect()
+        textpos.rightx = self._x + self._w - 1
+        textpos.centery = self._y + (self._h / 2)
+        surface.blit(text, textpos)
+
     def render_focus(self, surface):
         """ Render a default focus outline.
 
