@@ -61,11 +61,16 @@ class Label(IWidget):
     def render(self, surface):
         color, label_color = self.state_colors()
 
+        rect = ((self._x, self._y),
+                   (self._w, self._h))
+
+        pygame.draw.rect(surface, label_color, rect, 0)
+
         if self.alignment == Label.LEFT:
             self.render_left_text(surface, self.label, label_color)
         elif self.alignment == Label.CENTER:
             self.render_centered_text(surface, self.label, label_color)
-        elif self.alignment == label.RIGHT:
+        elif self.alignment == Label.RIGHT:
             self.render_right_text(surface, self.label, label_color)
 
     def can_focus(self):
